@@ -1,6 +1,6 @@
 package Data::SearchEngine::ElasticSearch;
 {
-  $Data::SearchEngine::ElasticSearch::VERSION = '0.18';
+  $Data::SearchEngine::ElasticSearch::VERSION = '0.19';
 }
 use Moose;
 
@@ -50,9 +50,6 @@ has 'transport' => (
 );
 
 
-sub engine { (shift)->_es }
-
-
 sub add {
     my ($self, $items, $options) = @_;
 
@@ -277,7 +274,7 @@ Data::SearchEngine::ElasticSearch - ElasticSearch support for Data::SearchEngine
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -402,10 +399,6 @@ The transport to use.  Refer to L<ElasticSearch> for more information.
 
 =head1 METHODS
 
-=head2 engine
-
-Returns the underlying search engine handle
-
 =head2 add ([ $items ])
 
 Add items to the index.  Keep in mind that the L<Data::SearchEngine::Item>
